==> haskell-yesod-form-1.4.16-84-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-form.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-form
version: 1.4.16
id: yesod-form-1.4.16-7hF5r7ISVRLF5PJGWQEBlJ
key: yesod-form-1.4.16-7hF5r7ISVRLF5PJGWQEBlJ
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Form handling support for Yesod Web Framework
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-form>.  Third-party packages which you can find useful: <http://hackage.haskell.org/package/yesod-form-richtext yesod-form-richtext> - richtext form fields (currntly it provides only Summernote support).
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Yesod.Form Yesod.Form.Bootstrap3 Yesod.Form.Fields
    Yesod.Form.Functions Yesod.Form.I18n.Chinese Yesod.Form.I18n.Czech
    Yesod.Form.I18n.Dutch Yesod.Form.I18n.English
    Yesod.Form.I18n.French Yesod.Form.I18n.German
    Yesod.Form.I18n.Japanese Yesod.Form.I18n.Korean
    Yesod.Form.I18n.Norwegian Yesod.Form.I18n.Portuguese
    Yesod.Form.I18n.Russian Yesod.Form.I18n.Spanish
    Yesod.Form.I18n.Swedish Yesod.Form.Input Yesod.Form.Jquery
    Yesod.Form.MassInput Yesod.Form.Nic Yesod.Form.Types
abi: 786ff4a6270f21dc3a138e7d7e09add6
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/yesod-form-1.4.16
library-dirs: /usr/lib/ghc-8.2.2/site-local/yesod-form-1.4.16
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/yesod-form-1.4.16
hs-libraries: HSyesod-form-1.4.16-7hF5r7ISVRLF5PJGWQEBlJ
depends:
    base-4.10.1.0 yesod-core-1.4.37.3-AwOMVH38UuVFbtGdnAcbdI
    yesod-persistent-1.4.3-5IM1E1KOCMkJrW017nbe8V time-1.8.0.2
    shakespeare-2.0.15-11zMuccFwzRGy8Rq2C5eb5
    persistent-2.7.3.1-3DupDoGujljIc8mXVCRDN0 template-haskell-2.12.0.0
    transformers-0.5.2.0 data-default-0.7.1.1-AA4CT1Ft3yBIiqFbrFdPSr
    xss-sanitize-0.3.5.7-1atuuUeUUWVEFq5EcL7PJg
    blaze-builder-0.4.0.2-DHYoGQYzHva8PydFQisCY7
    email-validate-2.3.2.1-BRWcGRRa1aQCXOO25fVaXH bytestring-0.10.8.2
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    wai-3.2.1.1-FFdyPRpWxQ97tBGJ3Vieeo containers-0.5.10.2
    blaze-html-0.9.0.1-2Wxj0X1c4OOA0Fs6NGHGGN
    blaze-markup-0.8.2.0-JO1Oy9jYgbGFSxqAItqjWc
    attoparsec-0.13.2.2-LZeWrUF9jJCLKiulgivlMd
    byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL
    aeson-1.2.4.0-9TsMr8JCMWWAuTOIqOHJIi
    resourcet-1.1.11-CBqlS4EKis96dPH3jRDN4i
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q
    network-uri-2.6.1.0-18L86fks2XD2OSuhve27bS
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             yesod-core-1.4.37.3-AwOMVH38UuVFbtGdnAcbdI=cab987c7de40d36c083e9bd2b4656df6
             yesod-persistent-1.4.3-5IM1E1KOCMkJrW017nbe8V=f9091c656c3c61cbcfe3a28202515ee8
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             shakespeare-2.0.15-11zMuccFwzRGy8Rq2C5eb5=bd2c877ae0e19551fc2cc21aba33ec99
             persistent-2.7.3.1-3DupDoGujljIc8mXVCRDN0=60e956938dad8fdee125bba3bf76f5bd
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             data-default-0.7.1.1-AA4CT1Ft3yBIiqFbrFdPSr=0186e0f4b96bc201d2baef8ade597d90
             xss-sanitize-0.3.5.7-1atuuUeUUWVEFq5EcL7PJg=0ffa4934f99b3b4b373aed2be8d3848a
             blaze-builder-0.4.0.2-DHYoGQYzHva8PydFQisCY7=4ded867b3c298ec132dad2104a7f7b70
             email-validate-2.3.2.1-BRWcGRRa1aQCXOO25fVaXH=1bedc422d756f5898b8bbf97b8923528
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             wai-3.2.1.1-FFdyPRpWxQ97tBGJ3Vieeo=f23fc7107acf0017818154e8027ca65c
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             blaze-html-0.9.0.1-2Wxj0X1c4OOA0Fs6NGHGGN=d4749ddd32d1bff43101b58ffdfa6b64
             blaze-markup-0.8.2.0-JO1Oy9jYgbGFSxqAItqjWc=8e9b9ff2cdf9e89a23593b7f85e59200
             attoparsec-0.13.2.2-LZeWrUF9jJCLKiulgivlMd=e2a8304e8e3d2a4e2c1322de5747978c
             byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL=d7caed3dfdc2cc9400ff9a46cbe7296d
             aeson-1.2.4.0-9TsMr8JCMWWAuTOIqOHJIi=678f7baab8d88792435c407def5321e2
             resourcet-1.1.11-CBqlS4EKis96dPH3jRDN4i=a99b4ff76a3d8e41052bf635c118f787
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=0f8a4b2bc8ee8ce3a5dab66f0eb14e7c
             network-uri-2.6.1.0-18L86fks2XD2OSuhve27bS=2690938855a63b0d59221887564a11f0
haddock-interfaces: /usr/share/doc/haskell-yesod-form/html/yesod-form.haddock
haddock-html: /usr/share/doc/haskell-yesod-form/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-form-1.4.16-85-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-form.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-form
version: 1.4.16
id: yesod-form-1.4.16-FykhDojKZXOFy4z3WmQkYt
key: yesod-form-1.4.16-FykhDojKZXOFy4z3WmQkYt
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Form handling support for Yesod Web Framework
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-form>.  Third-party packages which you can find useful: <http://hackage.haskell.org/package/yesod-form-richtext yesod-form-richtext> - richtext form fields (currntly it provides only Summernote support).
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Yesod.Form Yesod.Form.Bootstrap3 Yesod.Form.Fields
    Yesod.Form.Functions Yesod.Form.I18n.Chinese Yesod.Form.I18n.Czech
    Yesod.Form.I18n.Dutch Yesod.Form.I18n.English
    Yesod.Form.I18n.French Yesod.Form.I18n.German
    Yesod.Form.I18n.Japanese Yesod.Form.I18n.Korean
    Yesod.Form.I18n.Norwegian Yesod.Form.I18n.Portuguese
    Yesod.Form.I18n.Russian Yesod.Form.I18n.Spanish
    Yesod.Form.I18n.Swedish Yesod.Form.Input Yesod.Form.Jquery
    Yesod.Form.MassInput Yesod.Form.Nic Yesod.Form.Types
abi: 139a36a73cb511a9881d5d68e97b683b
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/yesod-form-1.4.16
library-dirs: /usr/lib/ghc-8.2.2/site-local/yesod-form-1.4.16
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/yesod-form-1.4.16
hs-libraries: HSyesod-form-1.4.16-FykhDojKZXOFy4z3WmQkYt
depends:
    base-4.10.1.0 yesod-core-1.4.37.3-Kpxc0d7LmKrBamG0ICPMei
    yesod-persistent-1.4.3-2D433f9k3v9BUiwKWXvMxC time-1.8.0.2
    shakespeare-2.0.15-ApJgKGAZ4Uv2szyxsx62II
    persistent-2.7.3.1-6IPJfmQxrAM2v1XHnbLURw template-haskell-2.12.0.0
    transformers-0.5.2.0 data-default-0.7.1.1-AA4CT1Ft3yBIiqFbrFdPSr
    xss-sanitize-0.3.5.7-GGWiVkNg6JR2ZsXi5tLOef
    blaze-builder-0.4.0.2-DHYoGQYzHva8PydFQisCY7
    email-validate-2.3.2.1-8ob9z5HUxvl4hd0IQ4NuAu bytestring-0.10.8.2
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    wai-3.2.1.1-FFdyPRpWxQ97tBGJ3Vieeo containers-0.5.10.2
    blaze-html-0.9.0.1-2Wxj0X1c4OOA0Fs6NGHGGN
    blaze-markup-0.8.2.0-JO1Oy9jYgbGFSxqAItqjWc
    attoparsec-0.13.2.2-6Afec3PTeJ8I3cxSKL61mm
    byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL
    aeson-1.2.4.0-LfzbQdLtEh8Dr9TGmQripa
    resourcet-1.1.11-CBqlS4EKis96dPH3jRDN4i
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q
    network-uri-2.6.1.0-18L86fks2XD2OSuhve27bS
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             yesod-core-1.4.37.3-Kpxc0d7LmKrBamG0ICPMei=9e9830e108be6484da698a6cd1df67be
             yesod-persistent-1.4.3-2D433f9k3v9BUiwKWXvMxC=8103a590bdb3ada456bd08cc5007cd33
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             shakespeare-2.0.15-ApJgKGAZ4Uv2szyxsx62II=441d448f1713f26d89f830043a0fe214
             persistent-2.7.3.1-6IPJfmQxrAM2v1XHnbLURw=6353032350dd62a1bc688da3655d0d71
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             data-default-0.7.1.1-AA4CT1Ft3yBIiqFbrFdPSr=0186e0f4b96bc201d2baef8ade597d90
             xss-sanitize-0.3.5.7-GGWiVkNg6JR2ZsXi5tLOef=7f0e904eaa9eaab036326cb5f836c8ac
             blaze-builder-0.4.0.2-DHYoGQYzHva8PydFQisCY7=4ded867b3c298ec132dad2104a7f7b70
             email-validate-2.3.2.1-8ob9z5HUxvl4hd0IQ4NuAu=ade31f395ce784d794499a5ac5c577a1
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             wai-3.2.1.1-FFdyPRpWxQ97tBGJ3Vieeo=f23fc7107acf0017818154e8027ca65c
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             blaze-html-0.9.0.1-2Wxj0X1c4OOA0Fs6NGHGGN=d4749ddd32d1bff43101b58ffdfa6b64
             blaze-markup-0.8.2.0-JO1Oy9jYgbGFSxqAItqjWc=8e9b9ff2cdf9e89a23593b7f85e59200
             attoparsec-0.13.2.2-6Afec3PTeJ8I3cxSKL61mm=dbf2a2c6556965dad88a2349e873212b
             byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL=d7caed3dfdc2cc9400ff9a46cbe7296d
             aeson-1.2.4.0-LfzbQdLtEh8Dr9TGmQripa=4a8adb8dc6357086bd8deb5249fe98d7
             resourcet-1.1.11-CBqlS4EKis96dPH3jRDN4i=a99b4ff76a3d8e41052bf635c118f787
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=0f8a4b2bc8ee8ce3a5dab66f0eb14e7c
             network-uri-2.6.1.0-18L86fks2XD2OSuhve27bS=2690938855a63b0d59221887564a11f0
haddock-interfaces: /usr/share/doc/haskell-yesod-form/html/yesod-form.haddock
haddock-html: /usr/share/doc/haskell-yesod-form/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
